import React, { useState, useEffect, useCallback } from 'react'
import { Input, AutoComplete, message, Popover, Select } from 'antd'
import { searchAdress } from '../../../../apis/process'
import { debounce, lngmkt, isObject } from '../../../../utils/index'

const SearchLocation = (props) => {

  const areaName = window?.globalConfig?.mapsettings?.areasettings?.areaName || ''
  const { value, onChange, schema, addons } = props
  const { disabled, placeholder, presetValue, coordSync } = schema
  const [options, setOptions] = useState([])

  const getAdress = async (value) => {
    const { code, data } = await searchAdress({ keywords: `${areaName}${value}`, region: areaName })
    if (code === '0') {
      setOptions(data?.pois)
    } else {
      message.error('请求错误!')
    }
  }

  const onSearch = async (value) => {
    getAdress(value)
  }

  const handleSearch = (value) => {
    onChange(value)
  }

  const onSelect = (value) => {
    let location = options.find(v => v.name === value)?.location
    if (location) {
      let array = location.split(',')
      let coord = lngmkt({ lng: array[0], lat: array[1] })
      if (coordSync) {
        let paths = Object.keys(addons.formData)
        let targetPath = null
        if (Array.isArray(paths)) {
          paths.forEach(v => {
            let values = addons.getValue(v)
            if (isObject(values)) {
              for (let key in values) {
                if (key === coordSync) {
                  targetPath = `${v}.${key}`
                }
              }
            }
          })
        }
        if (targetPath) {
          addons.setValue(targetPath, `${coord.x},${coord.y}`)
        }
      }
    }
    onChange(value)
  }

  useEffect(() => {
    if (addons) {
      addons.setValue(addons.dataPath, presetValue || '')
    }
  }, [presetValue])

  return (
    <AutoComplete
      style={{ width: '100%' }}
      options={(options || []).map(v => ({ label: v.name, value: v.name }))}
      onSelect={onSelect}
      onSearch={handleSearch}
    >
      <Input.Search
        value={value}
        placeholder={disabled ? (placeholder || '') : (placeholder || '请输入地址点击搜索或者回车')}
        enterButton
        onSearch={onSearch}
      />
    </AutoComplete>
  )
}

export default SearchLocation
